==> GeometricShapes-0.1.0.tar.gz: GeometricShapes-0.1.0/README.md <==
# Shapes
![Github Top Language](https://img.shields.io/github/languages/top/Bikram-ghuku/shapes)
![Github release](https://img.shields.io/github/v/release/Bikram-ghuku/shapes)
![Github License](https://img.shields.io/github/license/Bikram-ghuku/shapes)
![Github Workflow tests](https://github.com/Bikram-ghuku/shapes/actions/workflows/python-package.yml/badge.svg)
![Codecov result](https://codecov.io/gh/bikram-ghuku/shapes/branch/main/graph/badge.svg)

<h1> Shapes library</h1>

<h3>Bored of defining constants and using formula for finding area and perimeter of shape??</h3>
<h3>Download our shapes library and use it in your code for easy calculation of area and perimeter</h3>
  <h4> Provided an example for your help: </h4>
  <img src="https://raw.githubusercontent.com/Bikram-ghuku/shapes/main/assets/example2.png"></img>
  <h4>Output for the example: </h4>
  <img src="https://raw.githubusercontent.com/Bikram-ghuku/shapes/main/assets/example2_output.png"></img>
  <h3>The <a href="https://github.com/Bikram-ghuku/shapes/blob/main/main.py">main.py</a> is an example of the library use.</h3>
  
  ## To install the library
  #### Clone the repo
  ```shell
git clone https://github.com/Bikram-ghuku/shapes.git && cd shapes
  ```
  #### Build the library
  ```Python
pip install -r requirements.txt
python setup.py sdist bdist_wheel
  ```
  
  #### Install the repo from wheel 
  ```shell
cd dist && pip install GeometricShapes-0.1.0-py3-none-any.whl
  ```
  
  <h3>Supported shapes:</h3>
<table>
	<tr>
		<td><bold>Shapes</bold></td>
		<td><bold>Supported Functions</bold></td>
	</tr>
	<tr>
		<td>Rectangle</td>
		<td>Area, Perimeter</td>
	</tr>
	<tr>
		<td>Square</td>
		<td>Area, Perimeter</td>
	</tr>
	<tr>
		<td>Circle</td>
		<td>Area, Perimeter</td>
	</tr>
	<tr>
		<td>Triangle</td>
		<td>Area, Perimeter</td>
	</tr>
	<tr>
		<td>Ellipse</td>
		<td>Area, Perimeter</td>
	</tr>
	<tr>
		<td>Sphere</td>
		<td>Area, Volume</td>
	</tr>
	<tr>
		<td>Cylinder</td>
		<td>Total Surfce area, Lateral surface area, Volume</td>
	</tr>
</table>
<h4>Feel free to fork the repo and create pull request to fix error and/or new feature. :)</h4>

==> GeometricShapes-0.1.4.tar.gz: GeometricShapes-0.1.4/README.md <==
# Shapes
![Github Top Language](https://img.shields.io/github/languages/top/Bikram-ghuku/shapes)
![Github release](https://img.shields.io/github/v/release/Bikram-ghuku/shapes)
![Github License](https://img.shields.io/github/license/Bikram-ghuku/shapes)
![Github Workflow tests](https://github.com/Bikram-ghuku/shapes/actions/workflows/python-package.yml/badge.svg)
[![Codecov result](https://codecov.io/gh/bikram-ghuku/shapes/branch/main/graph/badge.svg)](https://codecov.io/gh/Bikram-ghuku/shapes)

<h1> Shapes library</h1>

<h3>Bored of defining constants and using formula for finding area and perimeter of shape??</h3>
<h3>Download our shapes library and use it in your code for easy calculation of area and perimeter</h3>
  <h4> Provided an example for your help: </h4>
  <img src="https://raw.githubusercontent.com/Bikram-ghuku/shapes/main/assets/example2.png"></img>
  <h4>Output for the example: </h4>
  <img src="https://raw.githubusercontent.com/Bikram-ghuku/shapes/main/assets/example2_output.png"></img>
  <h3>The <a href="https://github.com/Bikram-ghuku/shapes/blob/main/main.py">main.py</a> is an example of the library use.</h3>
  
  ## To build the library
  #### Clone the repo
  ```shell
git clone https://github.com/Bikram-ghuku/shapes.git && cd shapes
  ```
  #### Build the library
  ```Python
pip install -r requirements.txt
python setup.py sdist bdist_wheel
  ```
  ## Installing the library
  #### Install using pip
  ```shell
  pip install GeometricShapes
  ```
  #### Install the repo from wheel 
  ```shell
cd dist && pip install GeometricShapes-0.1.0-py3-none-any.whl
  ```
  
  <h3>Supported shapes:</h3>
<table>
	<tr>
		<td> Shapes </td>
		<td> Supported Functions</td>
	</tr>
	<tr>
		<td>Rectangle</td>
		<td>Area, Perimeter</td>
	</tr>
	<tr>
		<td>Square</td>
		<td>Area, Perimeter</td>
	</tr>
	<tr>
		<td>Circle</td>
		<td>Area, Perimeter</td>
	</tr>
	<tr>
		<td>Triangle</td>
		<td>Area, Perimeter</td>
	</tr>
	<tr>
		<td>Ellipse</td>
		<td>Area, Perimeter</td>
	</tr>
	<tr>
		<td>Sphere</td>
		<td>Area, Volume</td>
	</tr>
	<tr>
		<td>Cylinder</td>
		<td>Total Surface area, Lateral surface area, Volume</td>
	</tr>
</table>
<h4>Feel free to fork the repo and create pull request to fix error and/or new feature. :)</h4>
